@@ -28,8 +28,8 @@ static ETP: Once<Protocol> = Once::new();
 
 /// 创建一个简易传输协议实例
 pub fn init() {
-    if let Some(etp) = Protocol::new(PROTOCOL_ID) {
-        ETP.call_once(|| etp);
+    if let Ok(protocol) = Protocol::new(PROTOCOL_ID) {
+        ETP.call_once(|| protocol);
         task_stream::spawn(async move {
             loop {
                 let etp=ETP.get().unwrap();
